@@ -1,6 +1,6 @@
 #[allow(warnings)]
 pub fn get_disk_list() -> Vec<Vec<String>> {
-    use systemstat::{saturating_sub_bytes, Platform, System};
+    use get_sys_info::{saturating_sub_bytes, Platform, System};
     let sys = System::new();
     let mut re = vec![];
     match sys.mounts() {
